# Basics

## Changing help

A very simple example on how to change the help using the event callbacks 
is as follows:

!!! Example "Adjusting the help documentation"

    === "Help"
        ```txt 
        --8<-- 'examples/basics/adjust_help.out'
        ```

    === "Code"
        ```python 
        --8<-- 'examples/basics/adjust_help.py'
        ```

## Adapting options to arguments

Similarly we can switch options to arguments:

!!! Example "Switching options to arguments"
    === "Help"
        ```txt 
        --8<-- 'examples/basics/opts_to_args.out'
        ```

    === "Code"
        ```python 
        --8<-- 'examples/basics/opts_to_args.py'
        ```
